import React, { useState, useEffect, useCallback, useRef } from 'react'
import { Tree, Button } from 'antd'
import router from 'umi/router'
import Prompt from '@/components/Prompt'
import { fetch, fetchList, apis } from '@/utils/request'
import NodeLabel from './components/NodeLabel'

const getTrees = fetchList(apis.buildingOwnerInfo.getTrees)
const addNode = fetch(apis.buildingOwnerInfo.addNode)
const deleteNode = fetch(apis.buildingOwnerInfo.deleteNode)

export default props => {
  const nodeRef = useRef()
  const [promptVisible, setPromptVisible] = useState(false)
  const [treeData, setTreeData] = useState()

  const getTreeData = nodeData => {
    const query = nodeData ? {
      id: nodeData.id,
      name: nodeData.name,
      treeType: nodeData.treeType,
      nodeNumber: nodeData.nodeNumber,
    } : { treeType: 'phase' }

    getTrees(query).then(res => {
      setTreeData(res.filter(x => x && Object.keys(x).length))
    })
  }

  const showPrompt = (data) => {
    nodeRef.current = data
    setPromptVisible(true)
  }

  const handleNodeAdd = (promptData) => {
    setPromptVisible(false)
    const nodeData = nodeRef.current
    addNode({ data: {
      id: nodeData.id,
      name: nodeData.name,
      treeType: nodeData.treeType,
      nodeNumber: promptData,
    }}).then(() => {
      // 刷新页面, 重新请求数据
      getTreeData()
    })
  }

  const handleNodeDelete = (nodeData) => {
    deleteNode({ data: {
      id: nodeData.id,
      name: nodeData.name,
      treeType: nodeData.treeType,
      nodeNumber: nodeData.nodeNumber,
    }}).then(() => {
      // 刷新页面, 重新请求数据
      getTreeData()
    })
  }

  const handleBatchImport = () => {
    router.push('/property/buildingInfo/importExcel')
  }

  useEffect(() => {
    getTreeData()
  }, [])

  const renderTreeNodes = data => data.map(node => {
    return (      
      <Tree.TreeNode
        {...node}
        key={node.key}
        dataRef={node}
        title={(<NodeLabel data={node} onAdd={showPrompt} onDelete={handleNodeDelete} />)}
      >
        {
          node.children ? renderTreeNodes(node.children) : null
        }
      </Tree.TreeNode>
    )
  })

  return (
    <>
      <div>
        <Button type="primary" onClick={handleBatchImport}>批量导入小区楼栋信息</Button>
      </div>
      {
        treeData && treeData.length ? (
          <Tree loadData={getTreeData}>
            {renderTreeNodes(treeData)}
          </Tree>
        ) : (
          <p style={{ color: '#aaa', fontSize: '0.8em', textAlign: 'center', marginTop: '16px' }}>暂无数据</p>
        )
      }
      <Prompt visible={promptVisible} onOk={handleNodeAdd} />
    </>
  )
}
